@@ -1,7 +1,8 @@
 """Asynchronous Python client for the P1 Monitor API."""
 
-from .models import Phases, Settings, SmartMeter
-from .p1monitor import P1Monitor, P1MonitorConnectionError, P1MonitorError
+from .exceptions import P1MonitorConnectionError, P1MonitorError
+from .models import Phases, Settings, SmartMeter, WaterMeter
+from .p1monitor import P1Monitor
 
 __all__ = [
     "P1Monitor",
@@ -10,4 +11,5 @@ __all__ = [
     "SmartMeter",
     "Settings",
     "Phases",
+    "WaterMeter",
 ]
